
<!---
FrozenIsBool True
-->

##Example

Note that setting a propertize method in a derived class works also and overwrite the previous one. But we need to redefine the property. This will be automatic in the Classer.